package opentelemetry

  1. Overview
  2. Docs

Module Signal.DecodeSource

Decode signals from protobuf encoded strings, received over the wire

logs s is a list of log resources decoded from the protobuf encoded string s.

metrics s is a list of metrics resources decoded from the protobuf encoded string s.

traces s is a list of span resources decoded from the protobuf encoded string s.