package opentelemetry

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module Opentelemetry_ambient_context_typesSource

Storage implementation.

There is a singleton storage for a given program, responsible for providing ambient context to the rest of the program.

Sourcetype 'a key = 'a Hmap.key
Sourcemodule type STORAGE = sig ... end
Sourcetype storage = (module STORAGE)