package opentelemetry

  1. Overview
  2. Docs
Legend:
Page
Library
Module
Module type
Parameter
Class
Class type
Module type Opentelemetry_ambient_context_types.STORAGESource

Sourceval name : string

Name of the storage implementation.

Sourceval get_map : unit -> Hmap.t option

Get the hmap from the current ambient context, or None if there is no ambient context.

Sourceval with_map : Hmap.t -> (unit -> 'b) -> 'b

with_hmap h cb calls cb() in an ambient context in which get_map() will return h. Once cb() returns, the storage is reset to its previous value.

Sourceval create_key : unit -> 'a key

Create a new storage key, guaranteed to be distinct from any previously created key.

Sourceval get : 'a key -> 'a option
Sourceval with_binding : 'a key -> 'a -> (unit -> 'b) -> 'b
Sourceval without_binding : 'a key -> (unit -> 'b) -> 'b